@@ -1,6 +1,6 @@
 from gantt import *
 
-from gantt.gantt import _font_attributes, _not_worked_days, _my_svgwrite_drawing_wrapper, mm, cm
+from gantt.gantt import __LOG__, _font_attributes, _not_worked_days, _my_svgwrite_drawing_wrapper, mm, cm
 
 
 class _svgwrite_generator(svgwrite.Drawing):
@@ -25,8 +25,6 @@ class _svgwrite_generator(svgwrite.Drawing):
         for stylesheet in self._stylesheets:
             svg += stylesheet_template % stylesheet
         svg += self.tostring()
-        # if pretty:  # write easy readable XML file
-        #     svg += pretty_xml(svg, indent=indent)
         return svg 
 
 
@@ -34,13 +32,12 @@ class _svgwrite_generator(svgwrite.Drawing):
 class ProjectSpanish(Project):
     """ Inherits from Project, some translations of months and days. """
 
-    def make_svg_for_tasks(self, filename, today=None, start=None, end=None, scale=DRAW_WITH_DAILY_SCALE, title_align_on_left=False, offset=0):
+    def get_string_svg_for_tasks(self, today=None, start=None, end=None, scale=DRAW_WITH_DAILY_SCALE, title_align_on_left=False, offset=0):
         """
-        Draw gantt of tasks and output it to filename. If start or end are
+        Draw gantt of tasks and outputs the svg in str format. If start or end are
         given, use them as reference, otherwise use project first and last day
 
         Keyword arguments:
-        filename -- string, filename to save to OR file object
         today -- datetime.date of day marked as a reference
         start -- datetime.date of first day to draw
         end -- datetime.date of last day to draw
@@ -122,7 +119,6 @@ class ProjectSpanish(Project):
         
         return dwg.generate_svg_code(width=(maxx+1+offset/10)*cm, height=(pheight+3)*cm)
 
- 
 
 
     def _svg_calendar(self, maxx, maxy, start_date, today=None, scale=DRAW_WITH_DAILY_SCALE, offset=0):
@@ -283,7 +279,7 @@ class ProjectSpanish(Project):
 class HyperLinkedTask(Task):
     """ Inherits from Task, adds some link functionality to the title, resource, and lateral box """
 
-    def __init__(self, name, link_name=None, link_lateral=None, link_resource=None, start=None, stop=None, duration=None, depends_of=None, resources=None, percent_done=0, color=None, fullname=None, display=True, state=''):
+    def __init__(self, name, link_name=None, link_lateral=None, link_resource=None, start=None, target='_self', stop=None, duration=None, depends_of=None, resources=None, percent_done=0, color=None, fullname=None, display=True, state=''):
         """Hyper linked task
 
         Args:
@@ -293,6 +289,7 @@ class HyperLinkedTask(Task):
             link_resource (str, optional): link over the resource. Defaults to None.
             start ([type], optional): [description]. Defaults to None.
             stop ([type], optional): [description]. Defaults to None.
+            target -- str, default '_self'. Can be '_target' | '_self' ...etc
             duration ([type], optional): [description]. Defaults to None.
             depends_of ([type], optional): [description]. Defaults to None.
             resources ([type], optional): [description]. Defaults to None.
@@ -306,6 +303,7 @@ class HyperLinkedTask(Task):
         self.link_name = link_name
         self.link_resource = link_resource
         self.link_lateral = link_lateral
+        self.target = target
 
     def svg(self, prev_y=0, link=None, start=None, end=None, color=None, level=None, scale=DRAW_WITH_DAILY_SCALE, title_align_on_left=False, offset=0):
         """
@@ -440,7 +438,7 @@ class HyperLinkedTask(Task):
                                             opacity=0.85,
                                             )
         if self.link_lateral:
-            link = svg.add(svgwrite.container.Hyperlink(href=self.link_lateral))
+            link = svg.add(svgwrite.container.Hyperlink(href=self.link_lateral, target=self.target))
             link.add(svgwrite.base.Title('Link a OT'))
         if link:
             link.add(linea_lateral)
@@ -521,7 +519,7 @@ class HyperLinkedTask(Task):
         titulo = svgwrite.text.Text(self.fullname, insert=((tx)*mm, (y + 5)*mm), fill=_font_attributes()['fill'], stroke=_font_attributes()[
                     'stroke'], stroke_width=_font_attributes()['stroke_width'], font_family=_font_attributes()['font_family'], font_size=15)
         if self.link_name:
-            link = svg.add(svgwrite.container.Hyperlink(href=self.link_name))
+            link = svg.add(svgwrite.container.Hyperlink(href=self.link_name, target=self.target))
             link.add(svgwrite.base.Title('Ir a equipo'))
         if link:
             link.add(titulo)
@@ -535,7 +533,7 @@ class HyperLinkedTask(Task):
             recurso = svgwrite.text.Text("{0}".format(t), insert=(tx*mm, (y + 8.5)*mm), fill='purple', stroke=_font_attributes()[
                     'stroke'], stroke_width=_font_attributes()['stroke_width'], font_family=_font_attributes()['font_family'], font_size=15-5)
             if self.link_resource:
-                link = svg.add(svgwrite.container.Hyperlink(href=self.link_resource))
+                link = svg.add(svgwrite.container.Hyperlink(href=self.link_resource, target=self.target))
                 link.add(svgwrite.base.Title('Ir a grupo'))
             if link:
                 link.add(recurso)
@@ -547,16 +545,18 @@ class HyperLinkedTask(Task):
 class HiperLinkedProject(ProjectSpanish):    
     """ Inherits from ProjectSpanish, adds some link functionality to the title """
 
-    def __init__(self, name="", link=None, color=None):
+    def __init__(self, name="", target='_self', link=None, color=None):
         """Hiper linked project
 
         Args:
             name (str, optional): [description]. Defaults to "".
             link ([type], optional): [description]. Defaults to None.
+            target -- str, default '_self'. Can be '_target' | '_self' ...etc
             color ([type], optional): [description]. Defaults to None.
         """
         super().__init__(name, color)
         self.link = link
+        self.target = target
 
 
 
@@ -604,7 +604,7 @@ class HiperLinkedProject(ProjectSpanish):
                 link = None
                 titulo = svgwrite.text.Text('{0}'.format(self.name), insert=((6*level+3+offset)*mm, ((prev_y)*10+7)*mm), fill=_font_attributes()['fill'], stroke=_font_attributes()['stroke'], stroke_width=_font_attributes()['stroke_width'], font_family=_font_attributes()['font_family'], font_size=15+3)
                 if self.link:
-                    link = fprj.add(svgwrite.container.Hyperlink(href=self.link))
+                    link = fprj.add(svgwrite.container.Hyperlink(href=self.link, target=self.target))
                     link.add(svgwrite.base.Title('Ir a equipo'))
                 if link:
                     link.add(titulo)
